/***************************************************************************
                          pcmm.h  -  description
                             -------------------
    begin                : P be 22 12:46:35 CET 2002
    copyright            : (C) 2002 by Tom Potrusil
    email                : potrto@@centrum.cz
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef PCMM_H
#define PCMM_H

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include <kapp.h>
#include <kmainwindow.h>
#include <qsplitter.h>
#include <qlayout.h>
#include <kconfig.h>
#include <kaction.h>

#include "pdoublefilepanel.h"
#include "urldatabase/purldatabase.h"
#include "pcmm_general.h"
#include "stdslots.h"

/** 
 * @short Pcmm is the base class of the project
 * @author Tom Potrusil
 */
class Pcmm : public KMainWindow {
    Q_OBJECT
public:
    /** 
     * construtor
     */
    Pcmm(QWidget* parent=0, const char *name=0);
    
    /**
     * destructor
     */
    ~Pcmm();

    /**
     * @returns widget that contains left and right file panel
     */
    PDoubleFilePanel *filePanel();

    /**
     * static pointer to an instance of the Pcmm
     */
    static Pcmm *pcmm;
    static PURLDatabase *url_database;
    static StdSlots *stdslots;

protected:
    /**
     * Save options of this widget
     */
    void saveOptions();

    /**
     * Read options of this widget
     */
    void readOptions();
    
    virtual void saveProperties(KConfig *_cfg);
    virtual void readProperties(KConfig *_cfg);
    virtual bool queryExit();

private:
    PDoubleFilePanel *file_panel;
    QBoxLayout *button_bar_layout;
    KToolBar *button_bar;

private slots:
    void buttonbarOrientationChanged();

public:
    static KAction *quit;
    static KAction *conf;
    static KAction *save;
    static KAction *help;
    static KAction *find;

    static KAction *delete_file;
    static KAction *mkdir;
    static KAction *link;
    static KAction *rename;
    static KAction *copy;
    static KAction *move;
    static KAction *gourl;
    static KAction *go_file;
    static KAction *file_prop;

    static KAction *select;
    static KAction *deselect;
    static KAction *refresh;

    static KAction *leftbookmarks;
    static KAction *rightbookmarks;
    static KAction *configurebookmarks;

    static KAction *lpanel_conf;
    static KToggleAction *ldir_line;
    static KToggleAction *lpath_combo;
    static KToggleAction *linfo_line;
    static KToggleAction *lhidden_files;

    static KAction *rpanel_conf;
    static KToggleAction *rdir_line;
    static KToggleAction *rpath_combo;
    static KToggleAction *rinfo_line;
    static KToggleAction *rhidden_files;

    static KAction *view;
    static KAction *edit;

    static KAction *up;
    static KAction *home;
    static KAction *copy_clip;
    static KAction *cut;
    static KAction *paste;


    /** 
     * Popup menu for file 
     */
    static KPopupMenu *file_menu;

    /** 
     * id of file_menu 
     */
    static int file_menu_title_id;

    /**
     * Popup menu for general operations, e.g. mkdir etc
     */
    static KPopupMenu *operations_menu;

    /**
     * index of open width item in file menu
     */
    static int file_menu_open_with_id;
};

#endif
