/***************************************************************************
                          advancedconfigimpl.cpp  -  description
                             -------------------
    begin                : t z 17 2002
    copyright            : (C) 2002 by Tom Potrusil
    email                : potrto@centrum.cz
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU Advanced Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "advancedconfigimpl.h"

#include <kapp.h>
#include <kconfig.h>
#include <klocale.h>
#include "../pcmm.h"

AdvancedConfigImpl::AdvancedConfigImpl( QWidget *parent, const char *name )
: AdvancedConfig( parent, name ) {
    setup();
}

AdvancedConfigImpl::~AdvancedConfigImpl() {
}

void AdvancedConfigImpl::setup() {
    lcache->setChecked( Pcmm::pcmm->filePanel()->lFilePanel()->fileManager()->hasViewCache() );
    lfam->setChecked( Pcmm::pcmm->filePanel()->lFilePanel()->fileManager()->wantFam() );
    rcache->setChecked( Pcmm::pcmm->filePanel()->rFilePanel()->fileManager()->hasViewCache() );
    rfam->setChecked( Pcmm::pcmm->filePanel()->rFilePanel()->fileManager()->wantFam() );

    bool luse = Pcmm::pcmm->filePanel()->lFilePanel()->fileManager()->useFam();
    llabel->setText( QString("%1 %2 %3").arg(i18n("Left panel")).arg( luse ? i18n("uses") : i18n("doesn't use") ).arg(i18n("FAM service")));

    bool ruse = Pcmm::pcmm->filePanel()->rFilePanel()->fileManager()->useFam();
    rlabel->setText( QString("%1 %2 %3").arg(i18n("Right panel")).arg( ruse ? i18n("uses") : i18n("doesn't use") ).arg(i18n("FAM service")));
}

void AdvancedConfigImpl::applyChanges() {
    Pcmm::pcmm->filePanel()->lFilePanel()->fileManager()->setFam( lfam->isChecked() );
    Pcmm::pcmm->filePanel()->rFilePanel()->fileManager()->setFam( rfam->isChecked() );
    Pcmm::pcmm->filePanel()->lFilePanel()->fileManager()->useViewCache( lcache->isChecked() );
    Pcmm::pcmm->filePanel()->rFilePanel()->fileManager()->useViewCache( rcache->isChecked() );

    bool luse = Pcmm::pcmm->filePanel()->lFilePanel()->fileManager()->useFam();
    llabel->setText( QString("%1 %2 %3").arg(i18n("Left panel")).arg( luse ? i18n("uses") : i18n("doesn't use") ).arg(i18n("FAM service")));

    bool ruse = Pcmm::pcmm->filePanel()->rFilePanel()->fileManager()->useFam();
    rlabel->setText( QString("%1 %2 %3").arg(i18n("Right panel")).arg( ruse ? i18n("uses") : i18n("doesn't use") ).arg(i18n("FAM service")));
}

void AdvancedConfigImpl::readSettings() {
    KConfig *config = kapp->config();
    config->setGroup( LEFT_PANEL_KEY );
    lcache->setChecked( config->readBoolEntry( "Use cache", true ) );
    lfam->setChecked( config->readBoolEntry( "Want fam", true ) );
    config->setGroup( RIGHT_PANEL_KEY );
    rcache->setChecked( config->readBoolEntry( "Use cache", true ) );
    rfam->setChecked( config->readBoolEntry( "Want fam", true ) );

    bool luse = Pcmm::pcmm->filePanel()->lFilePanel()->fileManager()->useFam();
    llabel->setText( QString("%1 %2 %3").arg(i18n("Left panel")).arg( luse ? i18n("uses") : i18n("doesn't use") ).arg(i18n("FAM service")));

    bool ruse = Pcmm::pcmm->filePanel()->rFilePanel()->fileManager()->useFam();
    rlabel->setText( QString("%1 %2 %3").arg(i18n("Right panel")).arg( ruse ? i18n("uses") : i18n("doesn't use") ).arg(i18n("FAM service")));
}

void AdvancedConfigImpl::saveSettings() {
    KConfig *config = kapp->config();
    config->setGroup( LEFT_PANEL_KEY );
    config->writeEntry( "Use cache", lcache->isChecked() );
    config->writeEntry( "Want fam", lfam->isChecked() );
    config->setGroup( RIGHT_PANEL_KEY );
    config->writeEntry( "Use cache", rcache->isChecked() );
    config->writeEntry( "Want fam", rfam->isChecked() );
}

void AdvancedConfigImpl::defaultSettings() {
    lfam->setChecked( true );
    rfam->setChecked( true );
    lcache->setChecked( true );
    rcache->setChecked( true );
}
