/***************************************************************************
                          general.cpp  -  description
                             -------------------
    begin                : Ne z 8 2002
    copyright            : (C) 2002 by Tom Potrusil
    email                : potrto@centrum.cz
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "generalconfig.h"

#include <klocale.h>
#include <qlayout.h>
#include <qtabwidget.h>
#include <qgroupbox.h>
#include <qtoolbutton.h>
#include <qlabel.h>

static const char* const image0_data[] = { 
"16 16 53 1",
". c None",
"# c #000000",
"R c #080808",
"Q c #101010",
"Y c #181c18",
"K c #202020",
"w c #313031",
"X c #313431",
"W c #414041",
"V c #414441",
"g c #4a3018",
"E c #4a484a",
"U c #4a4c4a",
"l c #524c4a",
"h c #52504a",
"j c #525052",
"i c #5a5952",
"J c #6a6962",
"P c #6a6d6a",
"T c #8b8d8b",
"D c #949594",
"S c #9c999c",
"O c #9c9d9c",
"C c #a4a19c",
"M c #a4a1a4",
"N c #a4a5a4",
"I c #acaaac",
"B c #acaeac",
"F c #b47d41",
"v c #b4b2b4",
"u c #b4b6b4",
"A c #bdbabd",
"t c #bdbebd",
"k c #c5854a",
"H c #c5c2c5",
"s c #c5c6c5",
"r c #cdcacd",
"L c #cdcecd",
"z c #d5d2d5",
"q c #d5d6d5",
"x c #dedade",
"p c #dedede",
"a c #e6a562",
"G c #e6e2e6",
"o c #e6e6e6",
"y c #eeeae6",
"n c #eeeeee",
"m c #f6f6f6",
"e c #ffae62",
"d c #ffc283",
"c c #ffc683",
"f c #ffca8b",
"b c #ffd29c",
"......####......",
".....##.####.#..",
"....#.....####..",
"...........###..",
"..........####..",
".####...........",
"#abca#######....",
"#bcdeeeeeeee#...",
"#fdghhhihhjjh###",
"#dklmmnopqrstuvw",
"#dgxpyopzsABCDE.",
"#FhxxGpqrHuICJK.",
"#gLrqqzLHABMDE..",
"#jLtssHtuBNOPQ..",
"RtNIBBINMSDTE...",
"KEEUUUEEVWWXY..."};


GeneralConfig::GeneralConfig( QWidget* parent, const char* name )
: QFrame( parent, name ) {
    QPixmap image0( ( const char** ) image0_data );

    setCaption( i18n( "GeneralConfig" ) );
    setFrameShape( QFrame::NoFrame );
    setFrameShadow( QFrame::MShadow );

    QGridLayout *general_layout = new QGridLayout( parent );
    general_layout->setSpacing( 6 );
    general_layout->setMargin( 11 );

    QGroupBox *groupbox1 = new QGroupBox( parent, "groupbox1" );
    groupbox1->setTitle( i18n( "General options" ) );
    groupbox1->setColumnLayout( 0, Qt::Vertical );
    groupbox1->layout()->setSpacing( 0 );
    groupbox1->layout()->setMargin( 0 );
    QGridLayout *groupbox1layout = new QGridLayout( groupbox1->layout() );
    groupbox1layout->setAlignment( Qt::AlignTop );
    groupbox1layout->setSpacing( 6 );
    groupbox1layout->setMargin( 11 );

    save_conf = new QCheckBox( i18n("Save configuration on exit" ), groupbox1 );
    save_path = new QCheckBox( i18n("Save current path on exit" ), groupbox1 );

    groupbox1layout->addWidget( save_path, 0, 0 );
    groupbox1layout->addWidget( save_conf, 1, 0 );

    QFrame *line1 = new QFrame( groupbox1, "line1" );
    line1->setFrameStyle( QFrame::HLine | QFrame::Sunken );
    groupbox1layout->addMultiCellWidget( line1, 2, 2, 0, 3 );
    
    editor = new QLineEdit( groupbox1, "editor" );
    editor->setMinimumWidth( 250 );
    groupbox1layout->addWidget( editor, 3, 1 );

    QToolButton *browse_editor = new QToolButton( groupbox1, "browseeditor" );
    browse_editor->setPixmap( image0 );
    groupbox1layout->addWidget( browse_editor, 3, 2 );

    QLabel *editor_label = new QLabel( i18n( "Editor:" ), groupbox1, "editorlabel" );
    groupbox1layout->addWidget( editor_label, 3, 0 );

    QFrame *line2 = new QFrame( groupbox1, "line2" );
    line2->setFrameStyle( QFrame::HLine | QFrame::Sunken );
    groupbox1layout->addMultiCellWidget( line2, 4, 4, 0, 2 );
    
    QGridLayout *paths_layout = new QGridLayout;
    paths_layout->setSpacing( 6 );
    paths_layout->setMargin( 0 );

    database_file = new QLineEdit( groupbox1, "database_file" );
    paths_layout->addWidget( database_file, 0, 1 );

    QToolButton *browse_database_file = new QToolButton( groupbox1, "browsedatabase_file" );
    browse_database_file->setPixmap( image0 );
    paths_layout->addWidget( browse_database_file, 0, 2 );

    QLabel *database_file_label = new QLabel( i18n( "Database file" ), groupbox1, "database_filelabel" );
    paths_layout->addWidget( database_file_label, 0, 0 );

    tempfile = new QLineEdit( groupbox1, "tempfile" );
    paths_layout->addWidget( tempfile, 1, 1 );

    QToolButton *browse_tempfile = new QToolButton( groupbox1, "browsetempfile" );
    browse_tempfile->setPixmap( image0 );
    paths_layout->addWidget( browse_tempfile, 1, 2 );

    QLabel *tempfile_label = new QLabel( i18n( "Temporary directory:" ), groupbox1, "tempfilelabel" );
    paths_layout->addWidget( tempfile_label, 1, 0 );

    groupbox1layout->addMultiCellLayout( paths_layout, 5, 5, 0, 2 );

    general_layout->addWidget( groupbox1, 0, 0 );

    connect( browse_editor, SIGNAL( clicked() ), this, SLOT( slotBrowseEditor() ) );
    connect( browse_tempfile, SIGNAL( clicked() ), this, SLOT( slotBrowseTempFile() ) );
    connect( browse_database_file, SIGNAL( clicked() ), this, SLOT( slotBrowseDatabaseFile() ) );
}

GeneralConfig::~GeneralConfig() {
}

void GeneralConfig::slotBrowseTempFile() {
}

void GeneralConfig::slotBrowseDatabaseFile() {
}

void GeneralConfig::slotBrowseEditor() {
}
