/***************************************************************************
                          looknfeel.cpp  -  description
                             -------------------
    begin                : P z 6 2002
    copyright            : (C) 2002 by Tom Potrusil
    email                : potrto@centrum.cz
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "looknfeel.h"
#include <klocale.h>
#include <qlayout.h>
#include <qtabwidget.h>
#include <qgroupbox.h>

LookNFeel::LookNFeel( QWidget* parent, const char* name )
: QFrame( parent, name ) {
    setCaption( i18n( "Look & Feel" ) );
    setFrameShape( QFrame::NoFrame );
    setFrameShadow( QFrame::MShadow );

    QGridLayout *looknfeel_layout = new QGridLayout( parent );
    looknfeel_layout->setSpacing( 6 );
    looknfeel_layout->setMargin( 11 );

    QTabWidget *tab_widget = new QTabWidget( parent, "tabwidget" );
   
    // GENERAL TAB
    QWidget *general_tab = new QWidget( tab_widget, "generaltab" );
    QGridLayout *tab_layout1 = new QGridLayout( general_tab );
    tab_layout1->setSpacing( 6 );
    tab_layout1->setMargin( 11 );

    QGroupBox *groupbox1 = new QGroupBox( general_tab, "groupbox1" );
    groupbox1->setTitle( i18n( "Look & Feel" ) );
    groupbox1->setColumnLayout( 0, Qt::Vertical );
    groupbox1->layout()->setSpacing( 0 );
    groupbox1->layout()->setMargin( 0 );
    tab_layout1->addWidget( groupbox1, 0, 0 );

    // LEFT PANEL TAB
    QWidget *left_panel_tab = new QWidget( tab_widget, "leftpaneltab" );
    QGridLayout *tab_layout2 = new QGridLayout( left_panel_tab );
    tab_layout2->setSpacing( 6 );
    tab_layout2->setMargin( 11 );

    QGroupBox *groupbox2 = new QGroupBox( left_panel_tab, "groupbox2" );
    groupbox2->setTitle( i18n( "Options for left panel" ) );
    groupbox2->setColumnLayout( 0, Qt::Vertical );
    groupbox2->layout()->setSpacing( 0 );
    groupbox2->layout()->setMargin( 0 );
    left_panel_config = new PanelConfigImpl( true, groupbox2, "leftpanelconfig" );
    tab_layout2->addWidget( groupbox2, 0, 0 );

    // RIGHT PANEL TAB
    QWidget *right_panel_tab = new QWidget( tab_widget, "rightpaneltab" );
    QGridLayout *tab_layout3 = new QGridLayout( right_panel_tab );
    tab_layout3->setSpacing( 6 );
    tab_layout3->setMargin( 11 );

    QGroupBox *groupbox3 = new QGroupBox( right_panel_tab, "groupbox3" );
    groupbox3->setTitle( i18n( "Options for right panel" ) );
    groupbox3->setColumnLayout( 0, Qt::Vertical );
    groupbox3->layout()->setSpacing( 0 );
    groupbox3->layout()->setMargin( 0 );
    right_panel_config = new PanelConfigImpl( false, groupbox3, "rightpanelconfig" );
    tab_layout3->addWidget( groupbox3, 0, 0 );

    tab_widget->insertTab( general_tab, i18n("General") );
    tab_widget->insertTab( left_panel_tab, i18n("Left Panel") );
    tab_widget->insertTab( right_panel_tab, i18n("Right Panel") );

    looknfeel_layout->addWidget( tab_widget, 0, 0 );
}

LookNFeel::~LookNFeel() {
}

void LookNFeel::setup() {
    left_panel_config->setup();
    right_panel_config->setup();
}

void LookNFeel::applyChanges() {
    left_panel_config->applyChanges();
    right_panel_config->applyChanges();
}

void LookNFeel::defaultSettings() {
    left_panel_config->defaultSettings();
    right_panel_config->defaultSettings();
}
