/***************************************************************************
                          pdiskusagelabel.h  -  description
                             -------------------
    begin                : Mon May 6 2002
    copyright            : (C) 2002 by Tom Potrusil
    email                : potrto@centrum.cz
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/
#ifndef DISKUSAGELABEL_H
#define DISKUSAGELABEL_H

#include <qlabel.h>
#include "kdiskfreesp.h"
#include <qtimer.h>

#include "pfilemanager.h"

/**
 * Label that displays disk free space of the current partition.
 *
 * It uses @ref KDiskFreeSp to get know the disk usage. Informations
 * are checked every second.
 */
class PDiskUsageLabel: public QLabel {
    Q_OBJECT
public:
    PDiskUsageLabel( QWidget *parent, const char *name );
    ~PDiskUsageLabel();

    /**
     * Register @ref PFileManager of the widget's panel to
     * know current directory 
     */
    void registerManager( PFileManager *manager_ );

    /**
     * Parent of this widget (@ref PDirectoryLine) got focus
     */
    void focusInParent ();
    /**
     * Similar as above */
    void focusOutParent ();
private:
    PFileManager *manager;
    QTimer timer;
    KDiskFreeSp dfs;
bool working;

private slots:
    void showDiskUsage ( const unsigned long& kBSize, const unsigned long& kBUsed, const unsigned long& kBAvail, const QString& mountPoint );
    void done();
    void doTimer();

	
};

#endif
