/***************************************************************************
                          pfilepanel.h  -  description
                             -------------------
    begin                : Fri Mar 22 2002
    copyright            : (C) 2002 by Tom Potrusil
    email                : potrto@centrum.cz
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef PFILEPANEL_H
#define PFILEPANEL_H

#include <qwidget.h>
#include <qlayout.h>
#include <qlabel.h>
#include <kcombobox.h>
#include <kurl.h>
#include <kfileitem.h>
#include <kdirlister.h>

#include "pselectedfilesinfo.h"
#include "pfileview.h"
#include "pfilemanager.h"
#include "pdirectoryline.h"

/**
 * @short Panel that shows files and informations about them
 *
 * Panel that shows files and informations about them. It contains
 * a file viewer @ref PFileView, a widget for directory informations 
 * @ref PDirectoryLine, path combobox for new directory enter
 * and a status line @ref PSelectedFilesInfo.
 * The view emits requests to a manager @ref PFileManager.
 * @author Tom Potrusil
 */

class PFilePanel : public QWidget  {
    Q_OBJECT
    friend PFileView;
public:
    /**
     * @param is_left is the panel is left or right
     */
    PFilePanel( bool is_left, QWidget *parent=0, const char *name=0);
    ~PFilePanel();

    /**
     * @returns view that shows files
     */
    PFileView *fileView();

    /**
     * @returns manager that operates with physical files
     */
    PFileManager *fileManager();

    /**
     * @returns directory line
     */
    PDirectoryLine *directoryLine();

    /**
     * Shows @ref PDirectoryLine if @p show is true otherwise it is hidden
     * @see PFilePanel::isDirectoryLine
     */
    void showDirectoryLine( bool show = true );
    /**
     * Shows @ref KComboBox if @p show is true otherwise it is hidden
     * @see PFilePanel::isPathCombobox
     */
    void showPathCombobox( bool show = true );
    /**
     * Shows @ref PSelectedFilesInfo if @p show is true otherwise it is hidden
     * @see PFilePanel::isInfoLine
     */
    void showInfoLine( bool show = true );

    /**
     * @returns true if PDirectoryLine is shown
     * @see PFilePanel::showDirectoryLine
     */
    bool isDirectoryLine();
    /**
     * @returns true if KComboBox is shown
     * @see PFilePanel::showPathCombobox
     */
    bool isPathCombobox();
    /**
     * @returns true if PSelectedFilesInfo is shown
     * @see PFilePanel::showInfoLine
     */
    bool isInfoLine();

    /**
     * @returns true if this panel is left panel
     */
    bool isLeft() {
        return is_left;
    };

public slots:
    /**
     * Change the visibility of the PDirectoryLine
     * @see PFilePanel::showDirectoryLine, PFilePanel::isDirectoryLine
     */
    void toggleDirectoryLine();
    /**
     * Change the visibility of the KComboBox
     * @see PFilePanel::showPathCombobox, PFilePanel::isPathCombobox
     */
    void togglePathCombobox();
    /**
     * Change the visibility of the PSelectedFilesInfo
     * @see PFilePanel::showInfoLine, PFilePanel::isInfoLine
     */
    void toggleInfoLine();

    /**
     * Show configuration dialog
     */
    void configureDlg();

    /**
     * Show @p URL in the widgets of the panel
     */
    void ShowNewURL( KURL& );

    /**
     * Ask manager to change directory to @p dir
     */
    void ChangeDirectory( const QString& dir );

    void listAsOtherPanel();
    
    void listHome();
    
    void saveConfig();
    void saveCurrentPath();
signals:
    /**
     * Signal is emitted when the widget gets focus
     */
    void CurrentPanel( PFilePanel* );

    /**
     * Signal is emitted when visibility of the @ref PDirectoryLine changed.
     * @see PFilePanel::toggleDirectoryLine, PFilePanel::showDirectoryLine
     */
    void directoryLineShown( bool );
    /**
     * Signal is emitted when visibility of the @ref KComboBox changed.
     * @see PFilePanel::togglePathCombobox, PFilePanel::showPathCombobox
     */
    void pathComboboxShown( bool );
    /**
     * Signal is emitted when visibility of the @ref PSelectedFilesInfo changed.
     * @see PFilePanel::toggleInfoLine, PFilePanel::showInfoLine
     */
    void infoLineShown( bool );

protected:
    /**
     * @ref PFileView informs panel that it got focus
     */
    void focusInEventChild();

protected slots:
    void slotSelectedFiles();
    void slotCurrentFile( QListViewItem* );

private:
    QVBoxLayout *vbox;
    PDirectoryLine *directory_line;
    KHistoryCombo *path_combobox;
    PSelectedFilesInfo *info_line;	
    PFileView *file_view;
    PFileManager *file_manager;

    bool is_directory_line;
    bool is_path_combobox;
    bool is_info_line;

    bool is_left;
};

#endif
