/***************************************************************************
                          pfileviewcache.h  -  description
                             -------------------
    begin                : Mon May 6 2002
    copyright            : (C) 2002 by Tom Potrusil
    email                : potrto@centrum.cz
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/
#ifndef PFILEVIEWCACHE_H
#define PFILEVIEWCACHE_H

#include <qtimer.h>
#include <qobject.h>
#include "pfileview.h"

#define INTERVAL 1000

/**
 * @short Cache between PFileView and PFileManager
 *
 * This class implements file cache between @ref PFileView and
 * @ref PFileManager. Its purpose is to faster file operations
 * when fam service is on. For example when copying many small
 * files fam reports files one by one, manager needs to call
 * stat function on each one and send it to view. With cache
 * files are not shown one by one. Cache can be turned off, but
 * it is not implemented in the application
 */
class PFileViewCache: public QObject {
	Q_OBJECT
public:
	PFileViewCache( PFileView *view_, bool want_cache = true );
	~PFileViewCache();

	virtual void DeleteItem( KFileItem *file );
	virtual void DeleteItem( QString file );

	virtual void InsertItem( KFileItem *file, bool set_current = false, bool clear_view = false );

	virtual void UpdateItem( KFileItem *update, KFileItem* by );
	virtual void UpdateItem( KFileItem *file );

	virtual void setSelected( KFileItem *file, bool sel );
	virtual void setSelected( QString file, bool sel );

	virtual void UpdateView( KFileItemList& files_to_add, KFileItemList& files_to_remove, KFileItemList& files_to_update );
	virtual void InsertToView( KFileItemList& files_to_insert, QString new_current_file );

	KFileItemList& items( bool clear_cache = false );

	void ClearCache();
	void DeleteCache();
	void ClearView();

	void setCache( bool want_cache = true );
	bool hasCache();

protected:
	void ClearDeleted();
	void ClearInserted();

	KFileItem *SearchItem( KFileItem *file );

protected slots:
	void TimerDo();
	
private:
	void SetFileCurrent();
	KFileItem *current_file;

	KFileItemList cache;
	enum { INSERTED, DELETED, NONE } cache_type;
	QTimer timer;
	PFileView *view;

	bool use_cache;
	bool clear_view_on_insert;

	KFileItemList m_items;
	KFileItem *last_found;
	KFileItemList tmp;

};

#endif
