#include <klocale.h>

#include "pfinder.h"
#include "advanced.h"
#include "../pcmm.h"
#include "../pviewer/pviewer.h"

#include <qvariant.h>
#include <kcombobox.h>
#include <klineedit.h>
#include <klistview.h>
#include <qbuttongroup.h>
#include <qcheckbox.h>
#include <qgroupbox.h>
#include <qheader.h>
#include <qlabel.h>
#include <qpushbutton.h>
#include <qtoolbutton.h>
#include <qlayout.h>
#include <qtooltip.h>
#include <qwhatsthis.h>
#include <kapp.h>
#include <kiconloader.h>
#include <kmenubar.h>
#include <kconfig.h>
#include <kmessagebox.h>
#include <kstatusbar.h>
#include <kfileitem.h>
#include <kpopupmenu.h>
#include <kprocess.h>
#include <kfiledialog.h>
#include <ksqueezedtextlabel.h>

class ResultItem: public KListViewItem {
public:
    ResultItem(QListView *parent, KFileItem* m_file)
      : KListViewItem(
              parent,
              m_file->url().fileName(),
              m_file->url().directory(),
              m_file->isDir() ? QString("<DIR>") : KGlobal::locale()->formatNumber( m_file->size(), 0),
              m_file->timeString() ),
        file(m_file) {
        if( file )
            file->setExtraData( parent, this );
        };
    virtual ~ResultItem() {
        delete file;
    };

    KFileItem *fileInfo() {
        return file;
    };

private:
    KFileItem *file;
};

/* 
 *  Constructs a PFinder which is a child of 'parent', with the 
 *  name 'name'.' 
 */
PFinder::PFinder( const QString& current_dir, QWidget* parent,  const char* name )
    : KDialog( parent, name ), file_content_shown( true ), search( &query, this, "search" )
{
    if ( !name )
	setName( "PFinder" );
    setCaption( tr2i18n( "Find" ) );

    KConfig *config = kapp->config();
    config->setGroup("Finder");

    QGridLayout *PFinderLayout = new QGridLayout( this, 1, 1, 11, 6, "PFinderLayout"); 

    Layout11 = new QGridLayout( 0, 1, 1, 0, 6, "Layout11"); 
    Layout11->setColStretch( 4, 1 );

    named_combo = new KHistoryCombo( true, this, "named_combo" );
    named_combo->setHistoryItems( config->readListEntry( "Names history" ) );
    named_combo->setMaxCount( 20 );
    named_combo->setFocus();
    Layout11->addMultiCellWidget( named_combo, 0, 0, 1, 4 );

    QLabel *TextLabel1 = new QLabel( this, "TextLabel1" );
    TextLabel1->setText( tr2i18n( "Named" ) );
    Layout11->addWidget( TextLabel1, 0, 0 );

    name_case_sensitive = new QCheckBox( i18n("Case sensitive"), this, "name_case_sensitive" );
    name_case_sensitive->setChecked( true );
    Layout11->addWidget( name_case_sensitive, 1, 1 );

    name_regular_expression = new QCheckBox( i18n("Regular expression"), this, "name_regular_expression" );
    Layout11->addWidget( name_regular_expression, 1, 2 );

    name_part_match = new QCheckBox( i18n("Part match"), this, "name_part_match" );
    Layout11->addWidget( name_part_match, 1, 3 );

    lookin_combo = new KHistoryCombo( true, this, "lookin_combo" );
    lookin_combo->setHistoryItems( config->readListEntry( "Lookin history" ) );
    lookin_combo->setMaxCount( 20 );
    lookin_combo->setCurrentText( current_dir );
    Layout11->addMultiCellWidget( lookin_combo, 2, 2, 1, 4 );

    QLabel *TextLabel2 = new QLabel( this, "TextLabel2" );
    TextLabel2->setText( tr2i18n( "Look in" ) );
    Layout11->addWidget( TextLabel2, 2, 0 );

    search_subdirectories = new QCheckBox( this, "search_subdirectories" );
    search_subdirectories->setText( tr2i18n( "Search subdirectories" ) );
    search_subdirectories->setChecked( TRUE );
    Layout11->addMultiCellWidget( search_subdirectories, 3, 3, 1, 4 );

    add_button = new QPushButton( this, "add_button" );
    add_button->setText( tr2i18n( "&Add" ) );
    Layout11->addWidget( add_button, 2, 5 );

    QHBoxLayout *line_layout = new QHBoxLayout( 0, 0, 6, "line_layout" );
    search_content = new QCheckBox( this, "search_content" );
    search_content->setText( tr2i18n( "Search file content" ) );
    QFrame *line1 = new QFrame( this, "line1" );
    line1->setFrameStyle( QFrame::HLine | QFrame::Sunken );
    line_layout->addWidget( search_content );
    line_layout->addWidget( line1 );
    line_layout->setStretchFactor( line1, 1 );
    Layout11->addMultiCellLayout( line_layout, 4, 4, 0, 5 );

    content_label = new QLabel( i18n("Containing"), this );
    Layout11->addWidget( content_label, 5, 0 );

    content_combo = new KHistoryCombo( true, this, "content_combo" );
    content_combo->setHistoryItems( config->readListEntry( "Content history" ) );
    content_combo->setMaxCount( 20 );
    Layout11->addMultiCellWidget( content_combo, 5, 5, 1, 5 );

    content_case_sensitive = new QCheckBox( i18n("Case sensitive"), this, "content_case_sensitive" );
    content_case_sensitive->setChecked( true );
    Layout11->addWidget( content_case_sensitive, 6, 1 );

    content_regular_expression = new QCheckBox( i18n("Regular expression"), this, "content_regular_expression" );
    Layout11->addWidget( content_regular_expression, 6, 2 );

    advanced_button = new QPushButton( this, "advanced_button" );
    advanced_button->setText( tr2i18n( "Advanced..." ) );
    Layout11->addWidget( advanced_button, 7, 0 );

    advanced_line = new KLineEdit( this, "advanced_line" );
    advanced_line->setText( tr2i18n( "No advanced options" ) );
    advanced_line->setReadOnly( true );
    Layout11->addMultiCellWidget( advanced_line, 7, 7, 1, 5 );

    find_button = new QPushButton( this, "find_button" );
    find_button->setText( tr2i18n( "&Find Now" ) );
    Layout11->addWidget( find_button, 0, 5 );
    PFinderLayout->addLayout( Layout11, 0, 0 );
    
    QGroupBox *GroupBox1 = new QGroupBox( this, "GroupBox1" );
//    GroupBox1->setEnabled( FALSE );
    GroupBox1->setTitle( tr2i18n( "Result" ) );
    GroupBox1->setColumnLayout(0, Qt::Vertical );
    GroupBox1->layout()->setSpacing( 6 );
    GroupBox1->layout()->setMargin( 11 );
    GroupBox1Layout = new QVBoxLayout( GroupBox1->layout() );
    GroupBox1Layout->setAlignment( Qt::AlignTop );

    QButtonGroup *ButtonGroup1 = new QButtonGroup( GroupBox1, "ButtonGroup1" );
    QHBoxLayout *ButtonGroup1Layout = new QHBoxLayout( ButtonGroup1 );

    KIconLoader *icon = kapp->iconLoader();
    
    focus_button = new QToolButton( ButtonGroup1, "focus_button" );
    focus_button->setTextLabel( i18n( "Focus" ) );
    focus_button->setEnabled( false );
    focus_button->setIconSet( icon->loadIconSet( "redo", KIcon::Toolbar ) );
//    focus_button->setUsesTextLabel( true );

    view_button = new QToolButton( ButtonGroup1, "view_button" );
    view_button->setTextLabel( i18n( "View File" ) );
    view_button->setEnabled( false );
    view_button->setIconSet( icon->loadIconSet( "viewmag", KIcon::Toolbar ) );

    edit_button = new QToolButton( ButtonGroup1, "edit_button" );
    edit_button->setTextLabel( i18n( "Edit File" ), true );
    edit_button->setEnabled( false );
    edit_button->setIconSet( icon->loadIconSet( "edit", KIcon::Toolbar ) );

    delete_button = new QToolButton( ButtonGroup1, "delete_button" );
    delete_button->setTextLabel( i18n( "Delete File" ) );
    delete_button->setEnabled( false );
    delete_button->setIconSet( icon->loadIconSet( "editdelete", KIcon::Toolbar ) );

    cut_button = new QToolButton( ButtonGroup1, "cut_button" );
    cut_button->setTextLabel( i18n( "Cut File" ) );
    cut_button->setEnabled( false );
    cut_button->setIconSet( icon->loadIconSet( "editcut", KIcon::Toolbar ) );

    copy_button = new QToolButton( ButtonGroup1, "copy_button" );
    copy_button->setTextLabel( i18n( "Copy File" ) );
    copy_button->setEnabled( false );
    copy_button->setIconSet( icon->loadIconSet( "editcopy", KIcon::Toolbar ) );

    stop_button = new QToolButton( ButtonGroup1, "stop_button" );
    stop_button->setTextLabel( i18n( "Stop" ) );
    stop_button->setEnabled( false );
    stop_button->setIconSet( icon->loadIconSet( "stop", KIcon::Toolbar ) );

    ButtonGroup1Layout->addWidget( focus_button );
    ButtonGroup1Layout->addWidget( view_button );
    ButtonGroup1Layout->addWidget( edit_button );
    ButtonGroup1Layout->addWidget( delete_button );
    ButtonGroup1Layout->addWidget( cut_button );
    ButtonGroup1Layout->addWidget( copy_button );
    ButtonGroup1Layout->addWidget( stop_button );
    ButtonGroup1Layout->addStretch();

    GroupBox1Layout->addWidget( ButtonGroup1 );

    result_view = new KListView( GroupBox1, "result_view" );
    result_view->addColumn( tr2i18n( "Name" ) );
    result_view->addColumn( tr2i18n( "Path" ) );
    result_view->addColumn( tr2i18n( "Size" ) );
    result_view->addColumn( tr2i18n( "Date" ) );
    GroupBox1Layout->addWidget( result_view );

    PFinderLayout->addWidget( GroupBox1, 1, 0 );

    status_bar = new KSqueezedTextLabel( this, "status_bar" );
    PFinderLayout->addWidget( status_bar, 2, 0 );

    search_content->setChecked( config->readBoolEntry( "Show search content in finder", false ) );
    showSearchContent( search_content->isChecked() );

    add_menu = new KPopupMenu( this, "add_menu" );
    add_menu->insertItem( i18n("Browse..."), this, SLOT( addBrowsed() ) );
    add_menu->insertSeparator();
    add_menu->insertItem( i18n("Add Home Dir"), this, SLOT( addHomeDir() ) );
    add_menu->insertItem( i18n("Add /mnt Dirs"), this, SLOT( addMntdDir() ) );
    add_button->setPopup( add_menu );

    // signals and slots connections
    connect( named_combo, SIGNAL( returnPressed() ), find_button, SLOT( animateClick() ) );
    connect( lookin_combo, SIGNAL( returnPressed() ), find_button, SLOT( animateClick() ) );
    connect( content_combo, SIGNAL( returnPressed() ), find_button, SLOT( animateClick() ) );
    connect( focus_button, SIGNAL( clicked() ), this, SLOT( focusFile() ) );
    connect( view_button, SIGNAL( clicked() ), this, SLOT( viewFile() ) );
    connect( edit_button, SIGNAL( clicked() ), this, SLOT( editFile() ) );
    connect( cut_button, SIGNAL( clicked() ), this, SLOT( cutFile() ) );
    connect( delete_button, SIGNAL( clicked() ), this, SLOT( deleteFile() ) );
    connect( copy_button, SIGNAL( clicked() ), this, SLOT( copyFile() ) );
    connect( stop_button, SIGNAL( clicked() ), this, SLOT( stopSearching() ) );
    connect( find_button, SIGNAL( clicked() ), this, SLOT( startSearching() ) );
    connect( advanced_button, SIGNAL( pressed() ), this, SLOT( advancedOptions() ) );
    connect( search_content, SIGNAL( toggled( bool ) ), this, SLOT( showSearchContent( bool ) ) );
    connect( &search, SIGNAL( currentPath( const QString& )), this, SLOT( currentPath( const QString& ) ) );
    connect( &search, SIGNAL( finished() ), this, SLOT( finished() ) );
    connect( &search, SIGNAL( foundFiles( const KFileItemList& )), this, SLOT( foundFiles( const KFileItemList& ) ) );
}

/*  
 *  Destroys the object and frees any allocated resources
 */
PFinder::~PFinder() {
    KConfig *config = kapp->config();
    config->setGroup("Finder");
    config->writeEntry( "Show search content in finder", search_content->isChecked() );
    config->writeEntry( "Names history", named_combo->historyItems() );
    config->writeEntry( "Lookin history", lookin_combo->historyItems() );
    config->writeEntry( "Content history", content_combo->historyItems() );
    config->sync();
}

void PFinder::advancedOptions()
{
    Advanced dlg( &query, this );
    if (dlg.exec()) {
        QString s = setQueryToAdvancedString();
        if (!s.isNull())
            advanced_line->setText( setQueryToAdvancedString() );
        else
            advanced_line->setText( i18n("No advanced options"));
    }
}

void PFinder::copyFile()
{
    qWarning( "PFinder::copyFile(): Not implemented yet!" );
}

void PFinder::cutFile()
{
    qWarning( "PFinder::cutFile(): Not implemented yet!" );
}

void PFinder::deleteFile()
{
    KFileItem *current_file = 0;
    ResultItem *item = (ResultItem*)result_view->currentItem();
    if( item )
        current_file = item->fileInfo();
    else
        return;
    if( current_file ) {
        KIO::SimpleJob *job = KIO::file_delete( current_file->url(), false );
        connect( job, SIGNAL(result(KIO::Job*)), SLOT( resultDelete(KIO::Job*)));
        ResultItem *item = (ResultItem*)current_file->extraData(result_view);
        if( item ) {
            current_file = 0;
            delete item;
        }
    }
}

void PFinder::editFile()
{
    KFileItem *current_file = 0;
    ResultItem *item = (ResultItem*)result_view->currentItem();
    if( item )
        current_file = item->fileInfo();
    else
        return;
    if (!current_file || current_file->isDir() ) return;
    QString filePath = current_file->isLocalFile() ? current_file->url().path() : current_file->url().prettyURL();
    if (!current_file->isReadable() ) {
        KMessageBox::sorry(this, QString("%1 \"%2\"").arg(i18n("You do not have permission to read") ).arg(filePath) );
        return;
    }
    KProcess proc;
    KConfig *config = kapp->config();
    config->setGroup("General Options");
    QString edit = config->readEntry( "Editor", "kwrite" );
    proc << edit << filePath;
    if (!proc.start(KProcess::DontCare))
        KMessageBox::sorry( this, QString("%1 \"%2\"")
                .arg(i18n("Can't open"))
                .arg( filePath ) );
}

void PFinder::focusFile()
{
    KFileItem *current_file = 0;
    ResultItem *item = (ResultItem*)result_view->currentItem();
    if( item )
        current_file = item->fileInfo();
    else
        return;
    if( current_file ) {
        Pcmm::pcmm->filePanel()->currentFilePanel()->fileManager()->focusFile( current_file->url() );
        accept();
    }
}

void PFinder::startSearching()
{
    if( !lookin_combo->currentText().isEmpty() ) lookin_combo->addToHistory( lookin_combo->currentText() );
    if( !content_combo->currentText().isEmpty() ) content_combo->addToHistory( content_combo->currentText() );
    if( !named_combo->currentText().isEmpty() ) named_combo->addToHistory( named_combo->currentText() );
    if (saveToQuery() && query.buildRegExp()) {
        stop_button->setEnabled(true);
        focus_button->setEnabled( false );
        view_button->setEnabled( false );
        edit_button->setEnabled( false );
        delete_button->setEnabled( false );
        cut_button->setEnabled( false );
        copy_button->setEnabled( false );
        result_view->clear();
        find_button->setText( i18n("Stop") );
        disconnect( find_button, SIGNAL( clicked() ), this, SLOT( startSearching() ) );
        connect( find_button, SIGNAL( clicked() ), this, SLOT( stopSearching() ) );
        search.start();
    }
}

void PFinder::stopSearching()
{
    search.stop();
}

void PFinder::viewFile()
{
    KFileItem *current_file = 0;
    ResultItem *item = (ResultItem*)result_view->currentItem();
    if( item )
        current_file = item->fileInfo();
    else
        return;
    if (!current_file) return;
    PViewer::view( this, current_file->url().prettyURL(), current_file->mimetype() );
}

void PFinder::showSearchContent( bool show ) {
    if (show == file_content_shown) return;
    if (show) {
        content_label->show();
        content_combo->show();
        content_regular_expression->show();
        content_case_sensitive->show();
        file_content_shown = true;
    }
    else {
        content_label->hide();
        content_combo->hide();
        content_regular_expression->hide();
        content_case_sensitive->hide();
        file_content_shown = false;
    }
}

QString PFinder::setQueryToAdvancedString() {
    QString owner;
    QString owner_perm;
    switch( query.owner_read ) {
        case FinderQuery::NotContain:
            owner_perm = "-r";
            break;
        case FinderQuery::Contain:
            owner_perm = "+r";
            break;
        default:
            break;
    }
    switch( query.owner_write ) {
        case FinderQuery::NotContain:
            owner_perm = owner_perm + "-w";
            break;
        case FinderQuery::Contain:
            owner_perm = owner_perm + "+w";
            break;
        default:
            break;
    }
    switch( query.owner_exec ) {
        case FinderQuery::NotContain:
            owner_perm = owner_perm + "-x";
            break;
        case FinderQuery::Contain:
            owner_perm = owner_perm + "+x";
            break;
        default:
            break;
    }
    if (query.owner.isNull() ) {
        if ( !owner_perm.isNull() )
            owner = QString("%1: %2").arg(i18n("owner")).arg( owner_perm );
    }
    else
        if (!owner_perm.isNull())
            owner = QString("%1 %1: %2").arg(i18n("owner")).arg(query.owner).arg( owner_perm );
        else
            owner = QString("%1 %2").arg(i18n("owner")).arg(query.owner);

    QString group;
    QString group_perm;
    switch( query.group_read ) {
        case FinderQuery::NotContain:
            group_perm = "-r";
            break;
        case FinderQuery::Contain:
            group_perm = "+r";
            break;
        default:
            break;
    }
    switch( query.group_write ) {
        case FinderQuery::NotContain:
            group_perm = group_perm + "-w";
            break;
        case FinderQuery::Contain:
            group_perm = group_perm + "+w";
            break;
        default:
            break;
    }
    switch( query.group_exec ) {
        case FinderQuery::NotContain:
            group_perm = group_perm + "-x";
            break;
        case FinderQuery::Contain:
            group_perm = group_perm + "+x";
            break;
        default:
            break;
    }
    if (query.group.isNull() ) {
        if ( !group_perm.isNull() )
            group = QString("%1: %2").arg(i18n("group")).arg( group_perm );
    }
    else
        if (!group_perm.isNull())
            group = QString("%1 %1: %2").arg(i18n("group")).arg(query.group).arg( group_perm );
        else
            group = QString("%1 %2").arg(i18n("group")).arg(query.group);

    QString others;
    QString others_perm;
    switch( query.suid ) {
        case FinderQuery::NotContain:
            others_perm = "-suid";
            break;
        case FinderQuery::Contain:
            others_perm = "+suid";
            break;
        default:
            break;
    }
    switch( query.sgid ) {
        case FinderQuery::NotContain:
            others_perm = others_perm + "-sgid";
            break;
        case FinderQuery::Contain:
            others_perm = others_perm + "+sgid";
            break;
        default:
            break;
    }
    switch( query.sticky ) {
        case FinderQuery::NotContain:
            others_perm = others_perm + "-sticky";
            break;
        case FinderQuery::Contain:
            others_perm = others_perm + "+sticky";
            break;
        default:
            break;
    }
    if (!others_perm.isNull() )
            others = QString("%1: %2").arg(i18n("others")).arg( others_perm );

    QString permissions;
    if (!owner.isNull())
        permissions = owner + ", ";
    if (!group.isNull())
        permissions = permissions + group + ", ";
    if (!others.isNull())
        permissions = permissions + others + ", ";
    if (!permissions.isNull())
        permissions.truncate( permissions.length()-2 );

    QString tmp;
    switch( query.t_regular ) {
        case FinderQuery::NotContain:
            tmp = QString("-%1|").arg(i18n("regular file"));
            break;
        case FinderQuery::Contain:
            tmp = QString("+%1|").arg(i18n("regular file"));
        default:
            break;
    }
    switch( query.t_dir ) {
        case FinderQuery::NotContain:
            tmp = tmp + QString("-%1|").arg(i18n("directory"));
            break;
        case FinderQuery::Contain:
            tmp = tmp + QString("+%1|").arg(i18n("directory"));
        default:
            break;
    }
    switch( query.t_char ) {
        case FinderQuery::NotContain:
            tmp = tmp + QString("-%1|").arg(i18n("character device"));
            break;
        case FinderQuery::Contain:
            tmp = tmp + QString("+%1|").arg(i18n("character device"));
        default:
            break;
    }
    switch( query.t_block ) {
        case FinderQuery::NotContain:
            tmp = tmp + QString("-%1|").arg(i18n("block device"));
            break;
        case FinderQuery::Contain:
            tmp = tmp + QString("+%1|").arg(i18n("block device"));
        default:
            break;
    }
    switch( query.t_symlink ) {
        case FinderQuery::NotContain:
            tmp = tmp + QString("-%1|").arg(i18n("symbolic link"));
            break;
        case FinderQuery::Contain:
            tmp = tmp + QString("+%1|").arg(i18n("symbolic link"));
        default:
            break;
    }
    switch( query.t_fifo ) {
        case FinderQuery::NotContain:
            tmp = tmp + QString("-%1|").arg(i18n("fifo"));
            break;
        case FinderQuery::Contain:
            tmp = tmp + QString("+%1|").arg(i18n("fifo"));
        default:
            break;
    }
    switch( query.t_socket ) {
        case FinderQuery::NotContain:
            tmp = tmp + QString("-%1|").arg(i18n("socket"));
            break;
        case FinderQuery::Contain:
            tmp = tmp + QString("+%1|").arg(i18n("socket"));
        default:
            break;
    }

    QString type;
    if (!tmp.isNull()) {
        tmp.truncate( tmp.length()-1 );
        type = QString("%1: %2").arg(i18n("type")).arg(tmp);
    }

    QString size;
    if (query.size_type != FinderQuery::NotUsed ) {
        switch( query.size_type ) {
            case FinderQuery::More:
                size = QString("%1 ").arg(i18n("greater than"));
                break;
            case FinderQuery::MoreEq:
                size = QString("%1 ").arg(i18n("greater or equal to"));
                break;
            case FinderQuery::Eq:
                size = QString("%1 ").arg(i18n("equal to"));
                break;
            case FinderQuery::LessEq:
                size = QString("%1 ").arg(i18n("smaller or equal to"));
                break;
            case FinderQuery::Less:
                size = QString("%1 ").arg(i18n("smaller than"));
                break;
            default:
                break;
        }
        size = size + QString::number(query.size) + "B";
    }

    QString time;
    if (query.date_type != FinderQuery::NotUsed ) {
        switch( query.date_type ) {
            case FinderQuery::More:
                time = QString("%1 ").arg(i18n("newer than"));
                break;
            case FinderQuery::MoreEq:
                time = QString("%1 ").arg(i18n("newer or equal to"));
                break;
            case FinderQuery::Eq:
                time = QString("%1 ").arg(i18n("equal to"));
                break;
            case FinderQuery::LessEq:
                time = QString("%1 ").arg(i18n("older or equal to"));
                break;
            case FinderQuery::Less:
                time = QString("%1 ").arg(i18n("older than"));
                break;
            default:
                break;
        }
        time = time + QString( ctime(&query.time));
    }

    QString complement;
    if (query.complementary_names) 
        complement = i18n("complementary names");

    QString string;
    if (!permissions.isNull())
        string = permissions + "; ";
    if (!type.isNull())
        string = string + type + "; ";
    if (!size.isNull())
        string = string + size + "; ";
    if (!time.isNull())
        string = string + time + "; ";
    if (!complement.isNull())
        string = string + complement + "; ";
    if (!string.isNull())
        string.truncate( string.length()-2 );
    return string;
}

bool PFinder::saveToQuery() {
    query.patterns = QStringList::split( ';', named_combo->currentText() );
    if (query.patterns.isEmpty()) {
        KMessageBox::sorry( this, i18n("Named field is empty."));
        return false;
    }
    query.where_search.clear();
    QStringList list( QStringList::split( ';', lookin_combo->currentText() ) );
    for( QStringList::Iterator it = list.begin(); it != list.end(); ++it ) {
        KURL url( *it );
        if (!url.isValid()) {
            KMessageBox::sorry( this, i18n("You have entered invalid search directories."));
            return false;
        }
        else {
            for( KURL::List::Iterator urlit = query.where_search.begin(); urlit != query.where_search.end(); ++urlit )
                if (url.isParentOf( *urlit ))
                    urlit = query.where_search.remove( urlit );
            query.where_search.append( url );
        }
    }
    if (query.where_search.isEmpty()) {
        KMessageBox::sorry( this, i18n("Look-in field is empty."));
        return false;
    }
        
    query.pattern_case_sensitive = name_case_sensitive->isChecked();
    query.pattern_part_match = name_part_match->isChecked();
    query.pattern_regular_expression = name_regular_expression->isChecked();
    query.search_subdir = search_subdirectories->isChecked();
    query.search_content = (search_content->isChecked() && !content_combo->currentText().isEmpty() );
    //check if all directories are local
    if (query.search_content)
        for( KURL::List::Iterator it = query.where_search.begin(); it != query.where_search.end(); ++it )
            if (!(*it).isLocalFile()) {
                KMessageBox::sorry( this, i18n("I will turn off content searching.\nLook-in directories are not local."));
                query.search_content = false;
                break;
            }
    if (query.search_content) {
        query.content_case_sensitive = content_case_sensitive->isChecked();
        query.content_regular_expression = content_regular_expression->isChecked();
        query.containing = content_combo->currentText();
    }
    else {
        query.content_case_sensitive = true;
        query.content_regular_expression = false;
        query.containing = QString::null;
    }
    return true;
}

void PFinder::currentPath( const QString& path ) {
    status_bar->setText( path );
}

void PFinder::finished() {
    status_bar->setText( QString::null );
    find_button->setText( i18n("Find Now") );
    connect( find_button, SIGNAL( clicked() ), this, SLOT( startSearching() ) );
    disconnect( find_button, SIGNAL( clicked() ), this, SLOT( stopSearching() ) );
    stop_button->setEnabled(false);
    focus_button->setEnabled( true );
    view_button->setEnabled( true );
    edit_button->setEnabled( true );
    delete_button->setEnabled( true );
    cut_button->setEnabled( true );
    copy_button->setEnabled( true );
}

void PFinder::foundFiles( const KFileItemList& files ) {
    for( KFileItemListIterator it( files ); it.current(); ++it )
        new ResultItem( result_view, *it );
}

void PFinder::resultDelete( KIO::Job* job) {
    if( job->error() )
        job->showErrorDialog();
}

void PFinder::addMntdDir() {
    QDir d( "/mnt" );
    QString toadd;
    QStringList list = d.entryList( QDir::Dirs, QDir::Name );
    for( QStringList::Iterator it = list.begin(); it != list.end(); ++it ) {
        if( (*it) != "." && (*it) != ".." ) {
            toadd.append( QString("/mnt/%1;").arg( *it ) );
        }
    }
    if( !toadd.isNull() ) {
        toadd.truncate( toadd.length()-1 );
        lookin_combo->setCurrentText( toadd );
    }
}

void PFinder::addHomeDir() {
    lookin_combo->setCurrentText( getenv("HOME") );
}

void PFinder::addBrowsed() {
    QString start_dir = "/";
    QString dir = KFileDialog::getExistingDirectory( start_dir, 0, i18n("Select Directory"));
    if ( dir != QString::null )
        lookin_combo->setCurrentText(dir);
}

#include "pfinder.moc"
