/***************************************************************************
                          query.h  -  description
                             -------------------
    begin                : Ne z 29 2002
    copyright            : (C) 2002 by Tom Potrusil
    email                : potrto@centrum.cz
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef QUERY_H
#define QUERY_H

#include <qstring.h>
#include <qstringlist.h>
#include <qregexp.h>
#include <qvaluelist.h>
#include <kurl.h>

class FinderQuery {
public:
    FinderQuery();
    ~FinderQuery();

    bool buildRegExp();
    void setTime( int day, int month, int year );
    void setTime( int day, int month, int year, int hour, int minute, int second );
    bool fileMatch( const QString file_name );
    bool contentMatch( const QString line );

    QStringList patterns;
    bool pattern_case_sensitive;
    bool pattern_regular_expression;
    bool pattern_part_match;

    KURL::List where_search;

    bool search_subdir;
    
    // search content
    bool search_content;
    bool content_case_sensitive;
    bool content_regular_expression;
    QString containing;

    //advanced options

    //owner
    QString owner;
    enum { NotContain = 0, NotUsedPerm = 1, Contain = 2 };
    int owner_read;
    int owner_write;
    int owner_exec;

    //group
    QString group;
    int group_read;
    int group_write;
    int group_exec;

    //others
    int others_read;
    int others_write;
    int others_exec;

    //special
    int suid;
    int sgid;
    int sticky;

    //type
    int t_regular;
    int t_dir;
    int t_char;
    int t_block;
    int t_symlink;
    int t_fifo;
    int t_socket;

    //size, date, time
    enum { NotUsed = 0, More = 1, MoreEq = 2, Eq = 3, LessEq = 4, Less = 5 };
    int size_type;
    unsigned long size;
    int date_type;
    time_t time;

    //other options
    bool complementary_names;

    QValueList<QRegExp> name_regexp_list;
    QRegExp content_regexp;
};

#endif
