#ifndef URLLABEL_H
#define URLLABEL_H

#include <qlabel.h>

/**
 * This is a special label that dislays an URL. 
 * It allows user to click somewhere in the path and get it.
 */
class PURLLabel: public QLabel {
  Q_OBJECT
public:
	PURLLabel( QWidget * parent, const char * name = 0 );
	~PURLLabel();

	void setURL( const QString& url );

	/**
	 * Parent of the widget (@ref PFilePanel) got focus.
	 */
	void focusInParent ();
	/**
	 * Similar as above */
	void focusOutParent ();
signals:
	/**
	 * Emitted when the user clicked the left mouse button on this label.
	 *
	 * @param url The beginning of the URL for this label.
	 */ 
	void leftClickedURL(const QString& url);

	/**
	 * Emitted when the user clicked the left mouse button on this label.
	 */ 
	void leftClickedURL();

	/**
	 * Emitted when the user clicked the right mouse button on this label.
	 *
	 * @param url The beginning of the URL for this label.
	 */ 
	void rightClickedURL(const QString& url);

	/**
	 * Emitted when the user clicked the left mouse button on this label.
	 */ 
	void rightClickedURL();

	/**
	 * Emitted when the user clicked the middle mouse button on this label.
	 *
	 * @param url The beginning of the URL for this label.
	 */ 
	void middleClickedURL(const QString& url);

	/**
	 * Emitted when the user clicked the left mouse button on this label.
	 */ 
	void middleClickedURL();

	void currentURLChanged( const QString& url );

protected:
	void mouseReleaseEvent ( QMouseEvent* );
	void mouseMoveEvent ( QMouseEvent * );
	void enterEvent ( QEvent * );
	void leaveEvent ( QEvent * );

private slots:
	void changeText();

private:
	void setLinkColor (const QColor& col);

	QString current_url;
	QString old_current_url;
	QString rest_of_url;
	QString whole_url;

	bool working;

	QColor link_color;
	QColor highlighted_link_color;
};

#endif
