/***************************************************************************
                          stdslots.cpp  -  description
                             -------------------
    begin                : Ne j 6 2002
    copyright            : (C) 2002 by Tom Potrusil
    email                : potrto@centrum.cz
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "stdslots.h"
#include "pfileview.h"
#include "urldatabase/gourldialog.h"
#include "pviewer/pviewer.h"
#include "pcmm_general.h"
#include "pconfig/pconfig.h"
#include "pviewer/pviewer.h"
#include "pfinder/pfinder.h"

#include <kmessagebox.h>
#include <kprocess.h>
#include <kopenwith.h>

void StdSlots::saveURLDatabase() {
    Pcmm::url_database->save();
}

void StdSlots::loadURLDatabase() {
    Pcmm::url_database->load();
}

void StdSlots::Delete() {
    CURRENT_PANEL->fileView()->DeleteFiles();
}

void StdSlots::MkDir() {
    CURRENT_PANEL->fileManager()->MakeDirectory();
}

void StdSlots::Link() {
    CURRENT_PANEL->fileView()->LinkFiles();
}

void StdSlots::Rename() {
    CURRENT_PANEL->fileView()->RenameFile();
}

void StdSlots::Copy() {
    CURRENT_PANEL->fileView()->CopyFiles();
}

void StdSlots::CopyClip() {
    CURRENT_PANEL->fileView()->CopyFilesClip();
}

void StdSlots::Paste() {
    CURRENT_PANEL->fileView()->PasteFiles();
}

void StdSlots::Cut() {
    CURRENT_PANEL->fileView()->CutFiles();
}

void StdSlots::Move() {
    CURRENT_PANEL->fileView()->MoveFiles();
}

void StdSlots::Refresh() {
    CURRENT_PANEL->fileManager()->Update();
}

void StdSlots::Select() {
    CURRENT_PANEL->fileManager()->SelectFiles();
}

void StdSlots::Deselect() {
    CURRENT_PANEL->fileManager()->DeselectFiles();
}

void StdSlots::FileProperties() {
    CURRENT_PANEL->fileView()->FileProperties();
}

void StdSlots::FileEntered() {
    CURRENT_PANEL->fileView()->FileEntered();
}

void StdSlots::FileView() {
    KFileItem *file = CURRENT_PANEL->fileView()->currentFileItem();
    if (!file) return;
    PViewer::view( PCMM, file->url().prettyURL(), file->mimetype() );
}

void StdSlots::FileEdit() {
    KFileItem *file = CURRENT_PANEL->fileView()->currentFileItem();
    if (!file || file->isDir() ) return;
    QString filePath = file->isLocalFile() ? file->url().path() : file->url().prettyURL();
    if (!file->isReadable() ) {
        KMessageBox::sorry(PCMM,QString("%1 \"%2\"").arg(i18n("You do not have permission to read") ).arg(filePath) );
        return;
    }
    KProcess proc;
    KConfig *config = kapp->config();
    config->setGroup("General Options");
    QString edit = config->readEntry( "Editor", "kwrite" );
    proc << edit << filePath;
    if (!proc.start(KProcess::DontCare))
        KMessageBox::sorry( PCMM, QString("%1 \"%2\"")
                .arg(i18n("Can't open"))
                .arg( filePath ) );

}

void StdSlots::OpenWith() {
    KFileItem *file = CURRENT_PANEL->fileView()->currentFileItem();
    KURL::List lst( file->url() );
    KOpenWithDlg l( lst, i18n("Open With:"), QString::null, 0L );
    if ( l.exec() ) {
        KService::Ptr service = l.service();
        if ( !!service )
            KRun::run( *service, lst );
        else
            KRun::run( l.text(), lst );
    }
}

void StdSlots::GoURL() {
    GoURLDialog dlg( PCMM, i18n("Goto URL") );
    dlg.setCurrentDirectory( CURRENT_PANEL->fileManager()->CurrentDirectory() );
    if (dlg.exec())
            CURRENT_PANEL->ChangeDirectory( dlg.path_combobox->currentText() );
}

void StdSlots::configureBookmarks() {
    GoURLDialog dlg(PCMM, i18n("Configure bookmarks") );
    dlg.setBookmarksTabActive();
    dlg.setCurrentDirectory( CURRENT_PANEL->fileManager()->CurrentDirectory() );
    if (dlg.exec())
            CURRENT_PANEL->ChangeDirectory( dlg.path_combobox->currentText() );
}

void StdSlots::insertToURLDatabase( KURL& url ) {
    Pcmm::url_database->insert( PURLItem( url ) );
}

void StdSlots::leftBookmarks() {
    if (LEFT_PANEL->directoryLine() )
        LEFT_PANEL->directoryLine()->bookmarkButton()->animateClick();
}

void StdSlots::rightBookmarks() {
    if (RIGHT_PANEL->directoryLine())
        RIGHT_PANEL->directoryLine()->bookmarkButton()->animateClick();
}

void StdSlots::GoHome() {
    CURRENT_PANEL->listHome();
}

void StdSlots::GoUp() {
    CURRENT_PANEL->fileManager()->GoUp();
}

void StdSlots::invokeHelp() {
    kapp->invokeHelp();
}

void StdSlots::findFiles() {
    PFinder find( CURRENT_PANEL->fileManager()->CurrentDirectory().prettyURL(), PCMM );
    find.exec();
}

void StdSlots::configure() {
    PConfig dlg;
    dlg.exec();
}

void StdSlots::saveApplicationOptions() {
    //blbe reseni
    LEFT_PANEL->saveConfig();
    LEFT_PANEL->fileManager()->saveConfig();
    LEFT_PANEL->fileView()->saveConfig();
    RIGHT_PANEL->saveConfig();
    RIGHT_PANEL->fileManager()->saveConfig();
    RIGHT_PANEL->fileView()->saveConfig();
}
